<template>
  <ChatRepliedMessage v-if="reply_from_id && object?.replied_message  && status !== 'loading'" :replied-message="object?.replied_message" class="cursor-pointer" @click="viewReply()"/>

  <ReactionIcon :reaction-list="reactions"/>
  <div class="relative  bg-gray-400  rounded-md overflow-hidden w-full  block h-auto  aspect-square w-full mx-auto">

    <GoogleMap
        api-key="AIzaSyASeZ-2i6Vbv8NDhwdSd4Pq1pdoaiGAy1I"
        style="width: 100%; height: 100%"
        :center="{lat: parseFloat(object.location.latitude), lng: parseFloat(object.location.longitude)}"
        :zoom="15"
    >
      <Marker :options="markerOptions"/>
    </GoogleMap>
  </div>
    <div class="relative p-2 my-4 rounded-md bg-scheme-primary bg-opacity-10 block overflow-hidden text-sm whitespace-normal pb-2 text-gray-800"
          v-text="object.location.address">
    </div>
    <div :class="`relative flex items-end gap-5 justify-end` ">
      <div class="flex gap-1 items-center justify-end">
        <span class="block  text-xs text-gray-600 text-right select-none">{{ date }}</span>
        <!-- loading -->
        <template v-if="isSeller && !isLoader">
          <IcMessageStatus :status="status"/>
        </template>
      </div>
    </div>

  <div class="relative block pt-2 w-full border-t border-scheme-primary mt-2 border-opacity-10 text-center">
    <button @click="openMap(object.location.latitude, object.location.longitude)" class="btn !h-8 min-h-0 btn-link !no-underline rounded-0 normal-case relative block w-full font-medium text-sm text-scheme-primary">View Map</button>
  </div>

  <FailedSendMessage v-if="isSeller && status ==='failed'" :message="wa_error_message"/>
  <div v-if="is_forwarded === 1" class="absolute  -top-8 gap-1 rounded-tl-xl rounded-tr-xl left-0 block w-full  mt-4">
    <div class="relative flex py-2 items-center">
      <svg xmlns="http://www.w3.org/2000/svg" class="w-5 h-5 fill-current text-gray-400" viewBox="0 0 24 24"><path d="M21,12L14,5V9C7,10 4,15 3,20C5.5,16.5 9,14.9 14,14.9V19L21,12Z" /></svg>
      <span class="italic text-gray-400">Forwarded</span>
    </div>
  </div>
<!--  <div-->
<!--      :class="`relative flex gap-4 w-full ${isLoader ? 'animate-pulse': ''}  ${isSeller ? 'flex-row-reverse' : 'flex-row'}`">-->
<!--    <div-->
<!--        :class="`relative overflow-hidden w-14 h-14 ${isLoader ? 'bg-gray-400': 'bg-white shadow-md'}  rounded-full flex items-center ${isSeller ? 'order-2 p-2 ' : 'p-4 order-1'}`">-->
<!--      <div v-if="!isLoader" class="">-->

<!--        <ic-person-general />-->
<!--      </div>-->
<!--      &lt;!&ndash;        <Avatar :url="'https://source.unsplash.com/random/150x150/?avatar'"/>&ndash;&gt;-->
<!--    </div>-->
<!--    <div-->
<!--        :class="`relative w-1/4 mb-12 overflow-hidden shadow-sm pt-2 px-2 ${isSeller ? 'chat-right order-2 bg-scheme-primary bg-opacity-20' : 'chat-left order-1 bg-gray-100'} ${isLoader ? 'bg-gray-300': ''}`">-->
<!--      <div class="relative  bg-gray-400  rounded-md overflow-hidden w-full  block h-auto  aspect-square w-full mx-auto">-->

<!--        <GoogleMap-->
<!--            api-key="AIzaSyASeZ-2i6Vbv8NDhwdSd4Pq1pdoaiGAy1I"-->
<!--            style="width: 100%; height: 100%"-->
<!--            :center="{lat: parseFloat(object.location.latitude), lng: parseFloat(object.location.longitude)}"-->
<!--            :zoom="15"-->
<!--        >-->
<!--          <Marker :options="markerOptions"/>-->
<!--        </GoogleMap>-->
<!--      </div>-->
<!--      <div class="relative block pt-3 pb-6 px-2">-->
<!--        <div class="relative p-2 rounded-md bg-scheme-primary bg-opacity-10 block overflow-hidden text-sm whitespace-normal pb-2 text-gray-800"-->
<!--             v-text="object.location.address">-->
<!--        </div>-->
<!--        <span class="block absolute right-2 bottom-1 text-xs text-gray-600 mt-2 text-right select-none">{{-->
<!--            date-->
<!--          }}</span>-->
<!--      </div>-->
<!--      <div class="relative block w-full border-t border-scheme-primary border-opacity-10 p-2 text-center">-->
<!--        <button @click="openMap(object.location.latitude, object.location.longitude)"-->
<!--                class="relative block w-full py-1 font-medium text-sm text-scheme-primary">View location-->
<!--        </button>-->
<!--      </div>-->
<!--    </div>-->
<!--  </div>-->
</template>

<script setup lang="ts">

import {ref} from "vue";
// noinspection TypeScriptCheckImport
import { GoogleMap, Marker } from "vue3-google-map"
import IcPersonGeneral from "../Icon/IcPersonGeneral.vue";
import FailedSendMessage from "../Utility/FailedSendMessage.vue";
import IcMessageStatus from "../Icon/IcMessageStatus.vue";
import ReactionIcon from "../Icon/ReactionIcon.vue";
import ChatRepliedMessage from "./ChatRepliedMessage.vue";
import {useGeneralStore} from "../../stores/general";

interface Props {
  isSeller?: boolean
  is_forwarded?: number
  isLoader?: boolean
  date?: string
  message?: string
  wa_error_message?: string
  chatType?: string
  status?: string
  id?: bigint
  assignee?: object | null
  reactions?: any
  reply_from_id?: any
  object?: {
    location?: {
      address?: string | null
      latitude?: string | null
      longitude?: string | null
    },
    replied_message?: {
      message?: null,
      name?: null,
    },
    image?: {
      image_url?: null
    }
  }
}

let props = withDefaults(defineProps<Props>(), {
  isSeller: false,
  isLoader: false,
  is_forwarded: 0,
  date: null,
  status: null,
  assignee: null,
  chatType: null,
  message: null,
  wa_error_message: null,
  reactions: [],
  object: null,
});
const center = {lat: parseFloat(props.object.location.latitude), lng: parseFloat(props.object.location.longitude)}
const openMap = (latitude, longitude) => {
  return window.open(`https://www.google.com/maps/@${latitude},${longitude},20z`)
}
const markerOptions = { position: center }
const downloadProgress = ref(false)

const getFilename = (fileurl) => {
  if (fileurl) return fileurl.substring(fileurl.lastIndexOf('/') + 1)
}

const general = useGeneralStore()

const viewReply= () => {
  general.isShowReplyChat = !general.isShowReplyChat

  if(general.isShowReplyChat == true){
    general.isShowProfile = false
    general.replyChatId = props?.id
  }else{
    general.replyChatId = null
  }
}

const onDownload = (fileurl) => {
  downloadProgress.value = true

  setTimeout(() => {
    downloadProgress.value = false
    if (fileurl) {
      window.open(fileurl)
    }
  }, 1500)
}
</script>